@@ -1,13 +1,15 @@
-import os
 import logging
+import os
 
-from .io_utils import load_state, prepare_state
 from .web import Server, WebConfig
 
+
 def main(reset=False):
     logger = logging.getLogger()
     os.makedirs("data", exist_ok=True)
-    web_config = WebConfig("dataset.zip", "model", "data/unlabelled.json", "data/unstate.pkl")
+    web_config = WebConfig(
+        "dataset.zip", "model", "data/unlabelled.json", "data/unstate.pkl"
+    )
     if reset:
         logger.warning("RESET")
         web_config.reset()
@@ -17,6 +19,8 @@ def main(reset=False):
     server.plot()
     server.app.run_server(debug=False)
 
+
 if __name__ == "__main__":
-    from  fire import Fire
-    Fire(main)
\ No newline at end of file
+    from fire import Fire
+
+    Fire(main)
