@@ -5,7 +5,7 @@ from sklearn.preprocessing import MultiLabelBinarizer
 from torch.utils.data import Dataset
 from transformers import AutoTokenizer
 
-from .data_utils import compose, grouping_idx
+from .data_utils import compose, upsampling
 from .domain import Params
 
 random.seed(42)
@@ -77,9 +77,7 @@ class DatasetFactory:
         self.tokenizer = AutoTokenizer.from_pretrained(identifier)
 
     def supply_training_dataset(self):
-        x_train, y_train_raw = self._upsampling(
-            self.x_train_dict, self.y_train_tags, target=self.params.upsampling
-        )
+        x_train, y_train_raw = self._upsampling(self.x_train_dict, self.y_train_tags)
         y_train = self.mlb.transform(y_train_raw)
         x_test = list(map(compose, self.x_test_dict))
         y_test = self.mlb.transform(self.y_test_tags)
@@ -89,24 +87,7 @@ class DatasetFactory:
         testing_set = CustomDataset(x_test, self.tokenizer, self.params.max_len, y_test)
         return train_dataset, testing_set
 
-    def _upsampling(self, x, y, target=100):
-
-        group_by_idx = grouping_idx(y)
-        new_x = []
-        new_y = []
-        if target < 0:
-            shuffle = False
-            size = abs(target)
-        else:
-            shuffle = True
-            size = target
-        for group_idx in group_by_idx.values():
-            upsample_idx = random.choices(group_idx, k=size)
-            new_x.extend(
-                map(lambda idx: self._compose(x[idx], shuffle=shuffle), upsample_idx)
-            )
-            new_y.extend(map(lambda idx: y[idx], upsample_idx))
-        return new_x, new_y
-
-    def _compose(self, case, shuffle=True):
-        return compose(case, keep_key=self.params.keep_key, shuffle=shuffle)
+    def _upsampling(self, x: list, y: list):
+        return upsampling(
+            x, y, keep_key=self.params.keep_key, target=self.params.upsampling
+        )
